@@ -4,6 +4,9 @@ import pandas as pd
 
 
 def fis_tools_clean_df_columns(df):
+    """
+    Pasamos un DataFrame y nos lo devuelve con las columnas con un correcto formato para trabajo
+    """
     for col in df.columns:
         new_col = col.lower()
         new_col = new_col.replace(" ", "_")
@@ -19,6 +22,9 @@ def fis_tools_clean_df_columns(df):
     return df
     
 def fis_tools_frec_cat(df_cat):
+    """
+    Salida en formato DataFrame de la frecuencia de las variables categoricas en %
+    """
     resultado = df_cat.apply(lambda x: x.value_counts(normalize = True)).T.stack()\
                 .to_frame().reset_index()\
                 .rename(columns={'level_0':'Variable','level_1':'Valor',0: "Frecuencia"})\
@@ -26,6 +32,9 @@ def fis_tools_frec_cat(df_cat):
     return(resultado)
     
 def fis_tools_stats_cont(df_cont):
+    """
+    Salida en formato DataFrame de todos los estadísticos de variable contínua + mediana
+    """
     #Calculamos describe
     estadisticos = df_cont.describe().T
     #Añadimos la mediana
@@ -36,7 +45,9 @@ def fis_tools_stats_cont(df_cont):
     return(estadisticos)
     
 def fis_tools_graph_eda_cat(df_cat):
-    
+    """
+    Salida gráfica de todas las variables categoricas para exploration data analysis
+    """
     #Calculamos el número de filas que necesitamos
     from math import ceil
     filas = ceil(df_cat.shape[1] / 2)
@@ -54,7 +65,9 @@ def fis_tools_graph_eda_cat(df_cat):
         ax[cada].tick_params(labelsize = 12)
         
 def fis_tools_graph_eda_cont(df_cont):
-    
+    """
+    Salida gráfica de todas las variables continuas para exploration data analysis
+    """
     #Calculamos el número de fila que necesitamos
     from math import ceil
     filas = ceil(df_cont.shape[1] / 2)
@@ -72,17 +85,23 @@ def fis_tools_graph_eda_cont(df_cont):
         ax[cada].tick_params(labelsize = 12)
         
 #Función para agrupar categorías raras en 'OTROS'
-def fis_tools_group_cat_unknown(variable, criterio = 0.05):
+def fis_tools_group_cat_unknown(variable, criterio = 0.05,nombre='OTHERS'):
+    """
+    A partir del porcentaje de recurrencia (criterio) se agrupan N categorias en 1 sola nombre = 'OTHERS'
+    """
     #Calcula las frecuencias
     frecuencias = variable.value_counts(normalize=True)
     #Identifica las que están por debajo del criterio
     temp = [cada for cada in frecuencias.loc[frecuencias < criterio].index.values]
     #Las recodifica en 'OTROS'
-    temp2 = np.where(variable.isin(temp),'OTHERS',variable)
+    temp2 = np.where(variable.isin(temp),nombre,variable)
     #Devuelve el resultado
     return(pd.Series(temp2))
     
 def fis_tools_quitar_tildes(palabra):
+    """
+    Limpieza de tildes para análisis
+    """
     #Definimos la versión con tildes y símbolos y la sin
     con = 'áéíóúüñÁÉÍÓÚÜÑ'
     sin = 'aeiouunAEIOUUN'
@@ -92,6 +111,9 @@ def fis_tools_quitar_tildes(palabra):
     return(palabra.translate(traductor))
     
 def fis_tools_pre_strong_corr(df,lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
+    """
+    Extracción de variables correlacionadas a partir de un umbral lim_inf y tope lim_sup
+    """
     #Calcula la matriz de correlación
     c = df.corr().abs()
     #Lo pasa todo a filas
@@ -107,6 +129,9 @@ def fis_tools_pre_strong_corr(df,lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
     return(c)
     
 def fis_tools_pre_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
+    """
+    Salida Mejorada de la salida from sklearn.feature_selection import mutual_info_classif
+    """
     #Maqueta el ranking
     ranking_mi = pd.DataFrame(mutual_selector, index = predictors_df.columns).reset_index()
     ranking_mi.columns = ['variable','importancia_mi']
@@ -119,13 +144,29 @@ def fis_tools_pre_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
         g = ranking_mi[0:15].importancia_mi.sort_values().plot.barh()
         g.set_yticklabels(ranking_mi[0:15].sort_values(by = 'importancia_mi').variable)
         return(g)
+
+def fis_tools_pre_ranking_per(predictoras,rfe_ranking):
+    """
+    Salida Mejorada de la salida from sklearn.feature_selection import RFECV
+    """
+    rank_rfe = pd.DataFrame({'variable': predictoras.columns, 'ranking_rfe': rfe_ranking}).sort_values(by = 'ranking_rfe')
+    return(rank_rfe)
  
-def fis_tools_pre_ranking_per(predictoras,permutacion):
+def fis_tools_pre_ranking_per(predictoras,permutacion,modo='tabla'):
+    """
+    Salida Mejorada de la salida from sklearn.inspection import permutation_importance
+    """
     ranking_per = pd.DataFrame({'variable': predictoras.columns, 'importancia_per': permutacion.importances_mean}).sort_values(by = 'importancia_per', ascending = False)
     ranking_per['ranking_per'] = np.arange(0,ranking_per.shape[0])
-    return(ranking_per)
+    if modo = 'tabla':
+        return(ranking_per)
+    else:
+        ranking_per.set_index('variable').importancia_per.sort_values().plot.barh(figsize = (8,10));
     
 def fis_tools_pre_ranking_tot(rank_mi, rank_rfe,rank_per,modo='tabla'):
+    """
+    Comparativa de todos los rankings (mi, rfe, permutation) grafica y por tabla
+    """
     ranking_tot = pd.merge(pd.merge(rank_mi,rank_rfe),rank_per)
     ranking_tot['puntos'] = ranking_tot.ranking_mi + ranking_tot.ranking_rfe + ranking_tot.ranking_per
     ranking_tot.sort_values(by = 'puntos', inplace=True)
