@@ -4,8 +4,12 @@ import numpy as np
 import seaborn as sns
 import matplotlib.pyplot as plt
 from yellowbrick.classifier import discrimination_threshold
+from sklearn.metrics import PrecisionRecallDisplay
 
-def fis_machine_crear_lags(df, num_lags = 7):
+def fis_machine_date_lags(df, num_lags = 7):
+    """
+    Crea nuevas columnas en un DataFrame con los lags num_lags definidos (7 default)
+    """
     #Crea el objeto data frame
     lags = pd.Dataframe()
     #Crear todos los lags
@@ -13,13 +17,31 @@ def fis_machine_crear_lags(df, num_lags = 7):
         lags['lag_'+str(cada)] = df.shift(cada).iloc[:0]
     return(lags)
 
-def fis_machine_rolling_mean(df, num_periodos = 7):
+def fis_machine_date_rolling_mean(df, num_periodos = 7):
+    """
+    Crea num_periodos nuevas columnas en un DataFrame con la media movil de 1 a num_periodos
+    """
     mm = pd.DataFrame()
     for cada in range (1, num_periodos):
-        mm['mm_'+str(cada)] = df.shift(1).rolling(cada).mean().iloc[:,0]
+        mm['rm_'+str(cada)] = df.shift(1).rolling(cada).mean().iloc[:,0]
     return(mm)
 
-def fis_machine_metric_compute(real, scoring, umbral=0.5,graf_umbral=False,model=None,x=None,y=None):
+def fis_machine_metric_compute(real, scoring, umbral=0.5,graf_recall=False,graf_umbral=False,model=None,x=None,y=None):
+    """
+    umbral --> threshold de % de probabilidad a partir de la cual es True (1)  
+    
+    graf_recall(True)
+    -----------------
+    model --> el objeto sklearn model() instanciado
+    x --> variables predictoras (todas)
+    y --> target (todas)
+
+    graf_umbral (True)
+    ------------------
+    model --> el objeto sklearn model() instanciado
+    x --> variables predictoras (todas)
+    y --> target (todas)
+    """
     #CALCULAR LA DECISION SEGUN EL UMBRAL
     predicho = np.where(scoring > umbral,1,0)
     umbral_100 = umbral * 100
@@ -45,6 +67,9 @@ def fis_machine_metric_compute(real, scoring, umbral=0.5,graf_umbral=False,model
     print('Precision:',round(precision,3))
     print('Recall   :',round(recall,3))
     print('F1       :',round(F1,3))
+    if graf_recall:
+        PrecisionRecallDisplay.from_estimator(model,x,y)
+        plt.show()    
     if graf_umbral:
         discrimination_threshold(model,x,y, exclude = 'queue_rate')
         plt.show()
@@ -52,6 +77,7 @@ def fis_machine_metric_compute(real, scoring, umbral=0.5,graf_umbral=False,model
     
 def fis_machine_max_roi(real,scoring, salida = 'grafico',itn=0,ifp=-15,ifn=-85,itp=85):
     """
+    salida <> "grafico" devuelve valor numérico max ROI, para automatizaciones
     #DEFINIMOS LA MATRIZ DE IMPACTO
     itn   #true negatvie
     ifp   #false positive
